DeltaVctrl

Trait DeltaVctrl 

pub trait DeltaVctrl
where Self: Clone + Sized,
{ // Required methods fn ctrl_vector(&self, state: &Orbit) -> Vector3<f64>; fn next(&mut self, state: &Orbit); }
The DeltaVctrl trait handles control laws, optimizations, and other such methods for controlling the change in velocity of a point mass during a mission arc (MissionArc).

Required Methods

fn ctrl_vector(&self, state: &Orbit) -> Vector3<f64>

Returns the control vector corresponding to the change in velocity direction in the inertial frame.

fn next(&mut self, state: &Orbit)

Prepares the controller for the next maneuver (called from set_state of the dynamics).

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors